// Title:   MCTable.h
// Created: Thu Sep 25 15:11:34 2003
// Authors: Richard Keiser, Mark Pauly, Sascha Scandella
//
// Copyright (c) 2001, 2002, 2003, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef __MCTABLE_H_
#define __MCTABLE_H_

/**
 * This is a look-up table for a modified version of the Marching Cubes
 * algorithm. No disambiguation techniques are needed to produce a continuous
 * surface.
 *
 * For further information refer to "The Visual Computer", Vol. 10, pages 353-355
 * "A modified look-up table for implicit disambiguation of Marching Cubes"
 */

/* #0 */
{
	0,
	{-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	0,
	{ {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #1 */
{
	3,
	{ 0, 0, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 2, 4,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {2,0,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #2 */
{
	3,
	{ 0, 1, 1,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 5,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {2,1,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #3 */
{
	4,
	{ 0, 1, 0, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 2, 3, 4, 5,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,1,0}, {3,0,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #4 */
{
	3,
	{ 2, 0, 2,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 2, 6,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {2,1,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #5 */
{
	4,
	{ 0, 2, 0, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 4, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,0,1}, {2,1,3}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #6 */
{
	6,
	{ 0, 2, 0, 1, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 2, 3, 5, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {5,2,1}, {3,0,4}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #7 */
{
	5,
	{ 2, 1, 0, 1, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 3, 4, 5, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,4,1}, {1,4,3}, {3,4,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #8 */
{
	3,
	{ 2, 1, 3,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 3, 7,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {2,0,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #9 */
{
	6,
	{ 0, 2, 0, 1, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 2, 3, 4, 7,-1,-1,-1,-1,-1,-1},
	2,
	{ {4,0,2}, {1,3,5}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #10 */
{
	4,
	{ 0, 2, 1, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 7,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,1,0}, {3,0,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #11 */
{
	5,
	{ 2, 0, 0, 1, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 2, 4, 5, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {1,2,0}, {0,2,4}, {4,2,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #12 */
{
	4,
	{ 0, 1, 3, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 2, 3, 7, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,0,1}, {3,1,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #13 */
{
	5,
	{ 0, 1, 0, 3, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 4, 7, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {1,3,0}, {0,3,2}, {2,3,4}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #14 */
{
	5,
	{ 0, 0, 1, 3, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 2, 5, 7, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,2,1}, {1,2,4}, {4,2,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #15 */
{
	4,
	{ 0, 1, 3, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 4, 5, 7, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,3,1}, {3,0,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #16 */
{
	3,
	{ 4, 4, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 6, 4,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {1,0,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #17 */
{
	4,
	{ 0, 4, 0, 4,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 2, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,1,0}, {3,0,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #18 */
{
	6,
	{ 0, 4, 4, 1, 0, 1,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 6, 3, 4, 5,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,0,5}, {1,4,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #19 */
{
	5,
	{ 4, 0, 4, 1, 1,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 2, 6, 3, 5,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,3,0}, {0,3,2}, {2,3,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #20 */
{
	6,
	{ 2, 4, 0, 4, 0, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 2, 6, 4, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,4,3}, {5,2,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #21 */
{
	5,
	{ 0, 2, 4, 4, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 6, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {3,2,4}, {4,2,1}, {1,2,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #22 */
{
	9,
	{ 0, 2, 4, 0, 4, 1, 0, 1, 2,-1,-1,-1},
	{ 1, 3, 5, 2, 6, 3, 4, 5, 6,-1,-1,-1},
	3,
	{ {2,6,4}, {7,5,0}, {8,3,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #23 */
{
	6,
	{ 2, 4, 4, 1, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 6, 3, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {3,0,5}, {3,5,2}, {3,2,4}, {4,2,1}, {-1,-1,-1} }
},
/* #24 */
{
	6,
	{ 2, 4, 4, 1, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 6, 3, 4, 7,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,1,4}, {0,3,5}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #25 */
{
	7,
	{ 0, 2, 4, 0, 4, 1, 3,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 2, 6, 3, 7,-1,-1,-1,-1,-1},
	3,
	{ {4,2,0}, {4,0,3}, {1,5,6}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #26 */
{
	7,
	{ 0, 2, 4, 4, 0, 1, 3,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 6, 4, 5, 7,-1,-1,-1,-1,-1},
	3,
	{ {6,1,0}, {6,0,5}, {2,4,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #27 */
{
	6,
	{ 2, 4, 0, 4, 1, 3,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 2, 6, 5, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {3,0,2}, {0,3,5}, {5,3,1}, {1,4,5}, {-1,-1,-1} }
},
/* #28 */
{
	7,
	{ 4, 0, 4, 1, 0, 3, 2,-1,-1,-1,-1,-1},
	{ 5, 2, 6, 3, 4, 7, 6,-1,-1,-1,-1,-1},
	3,
	{ {3,5,6}, {3,6,1}, {4,2,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #29 */
{
	6,
	{ 0, 4, 4, 1, 3, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 6, 3, 7, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {2,4,5}, {4,2,1}, {4,1,3}, {0,3,1}, {-1,-1,-1} }
},
/* #30 */
{
	8,
	{ 0, 4, 0, 4, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 1, 5, 2, 6, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {2,0,5}, {2,5,7}, {7,5,6}, {4,3,1}, {-1,-1,-1} }
},
/* #31 */
{
	5,
	{ 4, 4, 1, 3, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 6, 5, 7, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {1,0,4}, {0,2,4}, {2,3,4}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #32 */
{
	3,
	{ 4, 5, 1,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 7, 5,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {0,1,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #33 */
{
	6,
	{ 0, 4, 0, 5, 0, 1,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 2, 7, 4, 5,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,5,1}, {4,0,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #34 */
{
	4,
	{ 0, 4, 5, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 7, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,2,3}, {1,3,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #35 */
{
	5,
	{ 4, 0, 5, 1, 0,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 2, 7, 3, 4,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,2,4}, {4,2,1}, {1,2,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #36 */
{
	6,
	{ 2, 4, 0, 5, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 2, 7, 5, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,3,4}, {2,0,5}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #37 */
{
	7,
	{ 0, 2, 4, 5, 0, 1, 2,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 7, 4, 5, 6,-1,-1,-1,-1,-1},
	3,
	{ {1,6,4}, {1,4,0}, {5,2,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #38 */
{
	7,
	{ 0, 2, 4, 0, 5, 1, 2,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 2, 7, 3, 6,-1,-1,-1,-1,-1},
	3,
	{ {2,4,5}, {2,5,0}, {3,1,6}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #39 */
{
	6,
	{ 2, 4, 5, 1, 0, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 7, 3, 4, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {1,5,4}, {5,1,2}, {5,2,0}, {3,0,2}, {-1,-1,-1} }
},
/* #40 */
{
	6,
	{ 2, 4, 5, 1, 1, 3,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 7, 3, 5, 7,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,3,5}, {2,4,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #41 */
{
	9,
	{ 0, 2, 4, 0, 5, 1, 0, 1, 3,-1,-1,-1},
	{ 1, 3, 5, 2, 7, 3, 4, 5, 7,-1,-1,-1},
	3,
	{ {4,7,2}, {8,1,5}, {6,0,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #42 */
{
	5,
	{ 0, 2, 4, 5, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 7, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,1,3}, {3,1,2}, {2,1,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #43 */
{
	6,
	{ 2, 4, 0, 5, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 2, 7, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {0,2,4}, {0,4,1}, {0,1,5}, {5,1,3}, {-1,-1,-1} }
},
/* #44 */
{
	7,
	{ 4, 0, 5, 1, 1, 3, 2,-1,-1,-1,-1,-1},
	{ 5, 2, 7, 3, 5, 7, 6,-1,-1,-1,-1,-1},
	3,
	{ {6,1,3}, {6,3,5}, {2,4,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #45 */
{
	8,
	{ 0, 4, 5, 1, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 1, 5, 7, 3, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {0,3,6}, {0,6,4}, {4,6,7}, {5,1,2}, {-1,-1,-1} }
},
/* #46 */
{
	6,
	{ 0, 4, 0, 5, 3, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 2, 7, 7, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {1,2,0}, {2,1,5}, {5,1,3}, {3,4,5}, {-1,-1,-1} }
},
/* #47 */
{
	5,
	{ 4, 5, 0, 3, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 7, 4, 7, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,1,2}, {1,3,2}, {3,4,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #48 */
{
	4,
	{ 4, 5, 0, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 6, 7, 4, 5,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,3,2}, {1,2,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #49 */
{
	5,
	{ 0, 0, 4, 5, 1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 2, 6, 7, 5,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,1,4}, {4,1,3}, {3,1,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #50 */
{
	5,
	{ 0, 4, 5, 1, 0,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 6, 7, 3, 4,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,1,0}, {0,1,3}, {3,1,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #51 */
{
	4,
	{ 0, 4, 5, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 2, 6, 7, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,1,3}, {1,2,3}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #52 */
{
	7,
	{ 2, 0, 4, 5, 0, 1, 2,-1,-1,-1,-1,-1},
	{ 3, 2, 6, 7, 4, 5, 6,-1,-1,-1,-1,-1},
	3,
	{ {3,5,4}, {3,4,2}, {6,1,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #53 */
{
	6,
	{ 0, 2, 4, 5, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 6, 7, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {1,4,0}, {4,1,3}, {3,1,5}, {5,2,3}, {-1,-1,-1} }
},
/* #54 */
{
	8,
	{ 0, 2, 0, 4, 5, 1, 0, 2,-1,-1,-1,-1},
	{ 1, 3, 2, 6, 7, 3, 4, 6,-1,-1,-1,-1},
	4,
	{ {0,6,3}, {0,3,5}, {5,3,4}, {2,1,7}, {-1,-1,-1} }
},
/* #55 */
{
	5,
	{ 2, 4, 5, 1, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 6, 7, 3, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,4,3}, {4,1,3}, {1,2,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #56 */
{
	7,
	{ 2, 4, 5, 1, 0, 1, 3,-1,-1,-1,-1,-1},
	{ 3, 6, 7, 3, 4, 5, 7,-1,-1,-1,-1,-1},
	3,
	{ {4,1,2}, {4,2,5}, {3,6,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #57 */
{
	8,
	{ 0, 2, 0, 4, 5, 1, 1, 3,-1,-1,-1,-1},
	{ 1, 3, 2, 6, 7, 3, 5, 7,-1,-1,-1,-1},
	4,
	{ {6,0,2}, {6,2,4}, {4,2,3}, {5,7,1}, {-1,-1,-1} }
},
/* #58 */
{
	6,
	{ 0, 2, 4, 5, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 6, 7, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {5,2,3}, {2,5,1}, {2,1,4}, {0,4,1}, {-1,-1,-1} }
},
/* #59 */
{
	5,
	{ 2, 0, 4, 5, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 2, 6, 7, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,0,3}, {0,1,3}, {1,2,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #60 */
{
	8,
	{ 0, 4, 5, 1, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 2, 6, 7, 3, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {1,5,4}, {1,2,5}, {7,3,6}, {7,0,3}, {-1,-1,-1} }
},
/* #61 */
{
	7,
	{ 0, 4, 5, 1, 1, 3, 2,-1,-1,-1,-1,-1},
	{ 1, 6, 7, 3, 5, 7, 6,-1,-1,-1,-1,-1},
	5,
	{ {1,2,4}, {1,4,0}, {6,0,3}, {6,3,5}, {1,0,6} }
},
/* #62 */
{
	7,
	{ 0, 0, 4, 5, 0, 3, 2,-1,-1,-1,-1,-1},
	{ 1, 2, 6, 7, 4, 7, 6,-1,-1,-1,-1,-1},
	5,
	{ {5,6,1}, {5,1,0}, {3,0,4}, {3,4,2}, {5,0,3} }
},
/* #63 */
{
	4,
	{ 4, 5, 3, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 6, 7, 7, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,2,3}, {0,1,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #64 */
{
	3,
	{ 6, 4, 2,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 6, 6,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {0,1,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #65 */
{
	6,
	{ 0, 6, 0, 4, 0, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 2, 6, 4, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,2,4}, {3,5,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #66 */
{
	6,
	{ 0, 6, 4, 1, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 6, 3, 5, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,2,5}, {3,0,4}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #67 */
{
	7,
	{ 6, 0, 4, 1, 0, 1, 2,-1,-1,-1,-1,-1},
	{ 7, 2, 6, 3, 4, 5, 6,-1,-1,-1,-1,-1},
	3,
	{ {5,3,1}, {5,1,4}, {2,6,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #68 */
{
	4,
	{ 2, 6, 0, 4,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 2, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,3,2}, {1,2,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #69 */
{
	5,
	{ 0, 2, 6, 4, 0,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 6, 4,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,0,3}, {3,0,2}, {2,0,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #70 */
{
	7,
	{ 0, 2, 6, 0, 4, 1, 1,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 2, 6, 3, 5,-1,-1,-1,-1,-1},
	3,
	{ {2,4,3}, {2,3,1}, {5,0,6}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #71 */
{
	6,
	{ 2, 6, 4, 1, 0, 1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 6, 3, 4, 5,-1,-1,-1,-1,-1,-1},
	4,
	{ {1,3,0}, {3,1,5}, {5,1,2}, {2,4,5}, {-1,-1,-1} }
},
/* #72 */
{
	6,
	{ 2, 6, 4, 1, 3, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 6, 3, 7, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,5,1}, {4,0,3}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #73 */
{
	9,
	{ 0, 2, 6, 0, 4, 1, 0, 3, 2,-1,-1,-1},
	{ 1, 3, 7, 2, 6, 3, 4, 7, 6,-1,-1,-1},
	3,
	{ {4,8,2}, {6,0,3}, {7,1,5}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #74 */
{
	7,
	{ 0, 2, 6, 4, 1, 3, 2,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 6, 5, 7, 6,-1,-1,-1,-1,-1},
	3,
	{ {0,4,5}, {0,5,1}, {6,2,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #75 */
{
	8,
	{ 2, 6, 0, 4, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 3, 7, 2, 6, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {0,2,4}, {0,4,6}, {6,4,5}, {7,1,3}, {-1,-1,-1} }
},
/* #76 */
{
	5,
	{ 6, 0, 4, 1, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 2, 6, 3, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,2,4}, {4,2,3}, {3,2,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #77 */
{
	6,
	{ 0, 6, 4, 1, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 6, 3, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {0,3,5}, {0,5,1}, {0,1,4}, {4,1,2}, {-1,-1,-1} }
},
/* #78 */
{
	6,
	{ 0, 6, 0, 4, 1, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 2, 6, 5, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {1,4,5}, {4,1,3}, {4,3,0}, {2,0,3}, {-1,-1,-1} }
},
/* #79 */
{
	5,
	{ 6, 4, 0, 1, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 6, 4, 5, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,1,4}, {1,2,4}, {2,3,4}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #80 */
{
	4,
	{ 6, 4, 0, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 4, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,2,3}, {1,3,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #81 */
{
	5,
	{ 0, 6, 4, 0, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 2, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,1,3}, {3,1,0}, {0,1,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #82 */
{
	7,
	{ 0, 6, 4, 1, 0, 1, 2,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 3, 4, 5, 6,-1,-1,-1,-1,-1},
	3,
	{ {6,1,2}, {6,2,4}, {0,5,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #83 */
{
	6,
	{ 6, 4, 0, 1, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 2, 3, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,0,1}, {0,4,3}, {0,3,5}, {2,5,3}, {-1,-1,-1} }
},
/* #84 */
{
	5,
	{ 2, 6, 4, 0, 0,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 2, 4,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {3,0,4}, {4,0,2}, {2,0,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #85 */
{
	4,
	{ 0, 2, 6, 4,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 5,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,2,0}, {2,3,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #86 */
{
	8,
	{ 0, 2, 6, 4, 0, 1, 0, 1,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 2, 3, 4, 5,-1,-1,-1,-1},
	4,
	{ {6,4,1}, {6,1,3}, {3,1,2}, {0,7,5}, {-1,-1,-1} }
},
/* #87 */
{
	5,
	{ 2, 6, 4, 1, 1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 3, 5,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,3,2}, {3,0,2}, {0,1,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #88 */
{
	7,
	{ 2, 6, 4, 1, 0, 3, 2,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 3, 4, 7, 6,-1,-1,-1,-1,-1},
	3,
	{ {2,4,6}, {2,6,1}, {5,0,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #89 */
{
	8,
	{ 0, 2, 6, 4, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 2, 3, 7, 6,-1,-1,-1,-1},
	4,
	{ {4,7,2}, {4,2,0}, {0,2,3}, {1,5,6}, {-1,-1,-1} }
},
/* #90 */
{
	8,
	{ 0, 2, 6, 4, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {2,4,7}, {2,3,4}, {6,0,5}, {6,1,0}, {-1,-1,-1} }
},
/* #91 */
{
	7,
	{ 2, 6, 4, 0, 1, 3, 2,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 2, 5, 7, 6,-1,-1,-1,-1,-1},
	5,
	{ {4,5,0}, {4,0,3}, {2,3,6}, {2,6,1}, {4,3,2} }
},
/* #92 */
{
	6,
	{ 6, 4, 0, 1, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 2, 3, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {3,4,2}, {4,3,1}, {1,3,5}, {5,0,1}, {-1,-1,-1} }
},
/* #93 */
{
	5,
	{ 0, 6, 4, 1, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 3, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {3,4,0}, {4,1,0}, {1,2,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #94 */
{
	7,
	{ 0, 6, 4, 0, 0, 1, 3,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 2, 4, 5, 7,-1,-1,-1,-1,-1},
	5,
	{ {1,2,4}, {1,4,3}, {6,3,0}, {6,0,5}, {1,3,6} }
},
/* #95 */
{
	4,
	{ 6, 4, 1, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 5, 7,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,2,3}, {0,1,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #96 */
{
	6,
	{ 6, 4, 4, 5, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 6, 7, 5, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {5,0,2}, {1,3,4}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #97 */
{
	9,
	{ 0, 6, 4, 0, 4, 5, 0, 1, 2,-1,-1,-1},
	{ 1, 7, 5, 2, 6, 7, 4, 5, 6,-1,-1,-1},
	3,
	{ {1,4,8}, {5,7,2}, {3,6,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #98 */
{
	7,
	{ 0, 6, 4, 4, 5, 1, 2,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 6, 7, 3, 6,-1,-1,-1,-1,-1},
	3,
	{ {5,0,2}, {5,2,4}, {1,3,6}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #99 */
{
	8,
	{ 6, 4, 0, 4, 5, 1, 0, 2,-1,-1,-1,-1},
	{ 7, 5, 2, 6, 7, 3, 4, 6,-1,-1,-1,-1},
	4,
	{ {6,1,4}, {6,4,2}, {2,4,5}, {3,7,0}, {-1,-1,-1} }
},
/* #100 */
{
	7,
	{ 2, 6, 4, 0, 4, 5, 1,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 2, 6, 7, 5,-1,-1,-1,-1,-1},
	3,
	{ {3,0,1}, {3,1,4}, {2,5,6}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #101 */
{
	8,
	{ 0, 2, 6, 4, 4, 5, 0, 1,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 6, 7, 4, 5,-1,-1,-1,-1},
	4,
	{ {4,6,0}, {4,0,2}, {2,0,1}, {3,5,7}, {-1,-1,-1} }
},
/* #102 */
{
	8,
	{ 0, 2, 6, 4, 0, 4, 5, 1,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 2, 6, 7, 3,-1,-1,-1,-1},
	4,
	{ {5,1,2}, {5,4,1}, {3,7,0}, {3,6,7}, {-1,-1,-1} }
},
/* #103 */
{
	7,
	{ 2, 6, 4, 4, 5, 1, 0,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 6, 7, 3, 4,-1,-1,-1,-1,-1},
	5,
	{ {0,1,3}, {0,3,6}, {5,6,2}, {5,2,4}, {0,6,5} }
},
/* #104 */
{
	9,
	{ 2, 6, 4, 4, 5, 1, 1, 3, 2,-1,-1,-1},
	{ 3, 7, 5, 6, 7, 3, 5, 7, 6,-1,-1,-1},
	3,
	{ {2,4,6}, {3,8,1}, {5,7,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #105 */
{
	12,
	{ 0, 2, 6, 4, 0, 4, 5, 1, 0, 1, 3, 2},
	{ 1, 3, 7, 5, 2, 6, 7, 3, 4, 5, 7, 6},
	4,
	{ {9,3,6}, {2,5,11}, {7,10,1}, {0,4,8}, {-1,-1,-1} }
},
/* #106 */
{
	8,
	{ 0, 2, 6, 4, 4, 5, 3, 2,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 6, 7, 7, 6,-1,-1,-1,-1},
	4,
	{ {5,6,1}, {5,1,3}, {3,1,0}, {2,4,7}, {-1,-1,-1} }
},
/* #107 */
{
	9,
	{ 2, 6, 4, 0, 4, 5, 0, 3, 2,-1,-1,-1},
	{ 3, 7, 5, 2, 6, 7, 4, 7, 6,-1,-1,-1},
	5,
	{ {2,5,7}, {2,7,3}, {2,3,6}, {7,0,3}, {4,8,1} }
},
/* #108 */
{
	8,
	{ 6, 4, 0, 4, 5, 1, 1, 3,-1,-1,-1,-1},
	{ 7, 5, 2, 6, 7, 3, 5, 7,-1,-1,-1,-1},
	4,
	{ {7,0,3}, {7,3,5}, {5,3,2}, {4,6,1}, {-1,-1,-1} }
},
/* #109 */
{
	9,
	{ 0, 6, 4, 4, 5, 1, 0, 1, 3,-1,-1,-1},
	{ 1, 7, 5, 6, 7, 3, 4, 5, 7,-1,-1,-1},
	5,
	{ {1,3,6}, {1,6,5}, {1,5,8}, {6,0,5}, {4,7,2} }
},
/* #110 */
{
	7,
	{ 0, 6, 4, 0, 4, 5, 3,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 2, 6, 7, 7,-1,-1,-1,-1,-1},
	5,
	{ {0,2,5}, {0,5,6}, {3,6,1}, {3,1,4}, {0,6,3} }
},
/* #111 */
{
	6,
	{ 6, 4, 4, 5, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 6, 7, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {0,2,4}, {0,4,5}, {5,4,1}, {5,1,3}, {-1,-1,-1} }
},
/* #112 */
{
	5,
	{ 6, 5, 0, 1, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 7, 4, 5, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {1,3,0}, {0,3,4}, {4,3,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #113 */
{
	6,
	{ 0, 6, 0, 5, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 2, 7, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,0,2}, {4,2,5}, {4,5,3}, {3,5,1}, {-1,-1,-1} }
},
/* #114 */
{
	6,
	{ 0, 6, 5, 1, 0, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 7, 3, 4, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {5,0,4}, {0,5,3}, {3,5,1}, {1,2,3}, {-1,-1,-1} }
},
/* #115 */
{
	5,
	{ 6, 0, 5, 1, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 2, 7, 3, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,0,1}, {0,2,1}, {2,3,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #116 */
{
	6,
	{ 2, 6, 0, 5, 0, 1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 2, 7, 4, 5,-1,-1,-1,-1,-1,-1},
	4,
	{ {3,0,1}, {0,3,5}, {0,5,2}, {4,2,5}, {-1,-1,-1} }
},
/* #117 */
{
	5,
	{ 0, 2, 6, 5, 1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 7, 5,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {3,4,2}, {4,0,2}, {0,1,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #118 */
{
	7,
	{ 0, 2, 6, 0, 5, 1, 0,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 2, 7, 3, 4,-1,-1,-1,-1,-1},
	5,
	{ {4,5,0}, {4,0,6}, {2,6,3}, {2,3,1}, {4,6,2} }
},
/* #119 */
{
	4,
	{ 2, 6, 5, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 7, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,2,3}, {0,1,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #120 */
{
	8,
	{ 2, 6, 5, 1, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 3, 7, 7, 3, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {1,2,5}, {1,5,7}, {7,5,4}, {6,0,3}, {-1,-1,-1} }
},
/* #121 */
{
	9,
	{ 0, 2, 6, 0, 5, 1, 1, 3, 2,-1,-1,-1},
	{ 1, 3, 7, 2, 7, 3, 5, 7, 6,-1,-1,-1},
	5,
	{ {4,6,0}, {4,0,8}, {4,8,2}, {0,3,8}, {7,1,5} }
},
/* #122 */
{
	7,
	{ 0, 2, 6, 5, 0, 3, 2,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 7, 4, 7, 6,-1,-1,-1,-1,-1},
	5,
	{ {4,6,2}, {4,2,3}, {0,3,5}, {0,5,1}, {4,3,0} }
},
/* #123 */
{
	6,
	{ 2, 6, 0, 5, 3, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 2, 7, 7, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,0,2}, {4,2,3}, {3,2,5}, {3,5,1}, {-1,-1,-1} }
},
/* #124 */
{
	7,
	{ 6, 0, 5, 1, 0, 1, 3,-1,-1,-1,-1,-1},
	{ 7, 2, 7, 3, 4, 5, 7,-1,-1,-1,-1,-1},
	5,
	{ {1,3,6}, {1,6,0}, {4,0,2}, {4,2,5}, {1,0,4} }
},
/* #125 */
{
	6,
	{ 0, 6, 5, 1, 1, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 7, 3, 5, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {2,4,0}, {2,0,1}, {1,0,3}, {1,3,5}, {-1,-1,-1} }
},
/* #126 */
{
	6,
	{ 0, 6, 0, 5, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 2, 7, 4, 7,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,5,1}, {0,4,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #127 */
{
	3,
	{ 6, 5, 3,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 7, 7,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {1,2,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #128 */
{
	3,
	{ 6, 5, 3,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 7, 7,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {1,0,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #129 */
{
	6,
	{ 0, 6, 0, 5, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 2, 7, 4, 7,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,1,5}, {0,2,4}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #130 */
{
	6,
	{ 0, 6, 5, 1, 1, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 7, 3, 5, 7,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,5,2}, {4,3,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #131 */
{
	7,
	{ 6, 0, 5, 1, 0, 1, 3,-1,-1,-1,-1,-1},
	{ 7, 2, 7, 3, 4, 5, 7,-1,-1,-1,-1,-1},
	3,
	{ {1,4,5}, {1,5,3}, {6,2,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #132 */
{
	6,
	{ 2, 6, 0, 5, 3, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 2, 7, 7, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,0,5}, {1,4,3}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #133 */
{
	7,
	{ 0, 2, 6, 5, 0, 3, 2,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 7, 4, 7, 6,-1,-1,-1,-1,-1},
	3,
	{ {4,0,1}, {4,1,6}, {2,5,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #134 */
{
	9,
	{ 0, 2, 6, 0, 5, 1, 1, 3, 2,-1,-1,-1},
	{ 1, 3, 7, 2, 7, 3, 5, 7, 6,-1,-1,-1},
	3,
	{ {2,7,4}, {8,3,1}, {6,5,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #135 */
{
	8,
	{ 2, 6, 5, 1, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 3, 7, 7, 3, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {3,0,7}, {3,7,5}, {5,7,4}, {6,2,1}, {-1,-1,-1} }
},
/* #136 */
{
	4,
	{ 2, 6, 5, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 7, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,1,0}, {2,0,3}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #137 */
{
	7,
	{ 0, 2, 6, 0, 5, 1, 0,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 2, 7, 3, 4,-1,-1,-1,-1,-1},
	3,
	{ {4,2,1}, {4,1,5}, {0,3,6}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #138 */
{
	5,
	{ 0, 2, 6, 5, 1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 7, 5,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {3,2,4}, {4,2,0}, {0,2,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #139 */
{
	6,
	{ 2, 6, 0, 5, 0, 1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 2, 7, 4, 5,-1,-1,-1,-1,-1,-1},
	4,
	{ {3,4,5}, {4,3,1}, {4,1,2}, {0,2,1}, {-1,-1,-1} }
},
/* #140 */
{
	5,
	{ 6, 0, 5, 1, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 2, 7, 3, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,1,0}, {0,1,2}, {2,1,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #141 */
{
	6,
	{ 0, 6, 5, 1, 0, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 7, 3, 4, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {2,0,3}, {0,2,4}, {4,2,1}, {1,5,4}, {-1,-1,-1} }
},
/* #142 */
{
	6,
	{ 0, 6, 0, 5, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 2, 7, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {2,0,4}, {2,4,3}, {2,3,5}, {5,3,1}, {-1,-1,-1} }
},
/* #143 */
{
	5,
	{ 6, 5, 0, 1, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 7, 4, 5, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {1,0,3}, {0,4,3}, {4,2,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #144 */
{
	6,
	{ 6, 4, 4, 5, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 6, 7, 4, 7,-1,-1,-1,-1,-1,-1},
	2,
	{ {4,2,1}, {3,0,5}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #145 */
{
	7,
	{ 0, 6, 4, 0, 4, 5, 3,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 2, 6, 7, 7,-1,-1,-1,-1,-1},
	3,
	{ {0,3,4}, {0,4,2}, {5,1,6}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #146 */
{
	9,
	{ 0, 6, 4, 4, 5, 1, 0, 1, 3,-1,-1,-1},
	{ 1, 7, 5, 6, 7, 3, 4, 5, 7,-1,-1,-1},
	3,
	{ {3,2,6}, {1,8,4}, {0,7,5}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #147 */
{
	8,
	{ 6, 4, 0, 4, 5, 1, 1, 3,-1,-1,-1,-1},
	{ 7, 5, 2, 6, 7, 3, 5, 7,-1,-1,-1,-1},
	4,
	{ {1,6,5}, {1,5,3}, {3,5,2}, {4,0,7}, {-1,-1,-1} }
},
/* #148 */
{
	9,
	{ 2, 6, 4, 0, 4, 5, 0, 3, 2,-1,-1,-1},
	{ 3, 7, 5, 2, 6, 7, 4, 7, 6,-1,-1,-1},
	3,
	{ {5,1,7}, {2,6,4}, {0,8,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #149 */
{
	8,
	{ 0, 2, 6, 4, 4, 5, 3, 2,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 6, 7, 7, 6,-1,-1,-1,-1},
	4,
	{ {7,4,3}, {7,3,1}, {1,3,0}, {2,6,5}, {-1,-1,-1} }
},
/* #150 */
{
	12,
	{ 0, 2, 6, 4, 0, 4, 5, 1, 0, 1, 3, 2},
	{ 1, 3, 7, 5, 2, 6, 7, 3, 4, 5, 7, 6},
	4,
	{ {8,5,3}, {6,2,10}, {0,9,7}, {4,1,11}, {-1,-1,-1} }
},
/* #151 */
{
	9,
	{ 2, 6, 4, 4, 5, 1, 1, 3, 2,-1,-1,-1},
	{ 3, 7, 5, 6, 7, 3, 5, 7, 6,-1,-1,-1},
	5,
	{ {3,2,6}, {3,6,0}, {3,0,8}, {6,5,0}, {1,7,4} }
},
/* #152 */
{
	7,
	{ 2, 6, 4, 4, 5, 1, 0,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 6, 7, 3, 4,-1,-1,-1,-1,-1},
	3,
	{ {0,5,4}, {0,4,1}, {3,2,6}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #153 */
{
	8,
	{ 0, 2, 6, 4, 0, 4, 5, 1,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 2, 6, 7, 3,-1,-1,-1,-1},
	4,
	{ {3,4,5}, {3,0,4}, {6,1,7}, {6,2,1}, {-1,-1,-1} }
},
/* #154 */
{
	8,
	{ 0, 2, 6, 4, 4, 5, 0, 1,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 6, 7, 4, 5,-1,-1,-1,-1},
	4,
	{ {7,5,2}, {7,2,0}, {0,2,1}, {3,6,4}, {-1,-1,-1} }
},
/* #155 */
{
	7,
	{ 2, 6, 4, 0, 4, 5, 1,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 2, 6, 7, 5,-1,-1,-1,-1,-1},
	5,
	{ {3,4,2}, {3,2,6}, {0,6,5}, {0,5,1}, {3,6,0} }
},
/* #156 */
{
	8,
	{ 6, 4, 0, 4, 5, 1, 0, 2,-1,-1,-1,-1},
	{ 7, 5, 2, 6, 7, 3, 4, 6,-1,-1,-1,-1},
	4,
	{ {0,7,2}, {0,2,4}, {4,2,5}, {3,1,6}, {-1,-1,-1} }
},
/* #157 */
{
	7,
	{ 0, 6, 4, 4, 5, 1, 2,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 6, 7, 3, 6,-1,-1,-1,-1,-1},
	5,
	{ {5,4,1}, {5,1,6}, {0,6,3}, {0,3,2}, {5,6,0} }
},
/* #158 */
{
	9,
	{ 0, 6, 4, 0, 4, 5, 0, 1, 2,-1,-1,-1},
	{ 1, 7, 5, 2, 6, 7, 4, 5, 6,-1,-1,-1},
	5,
	{ {5,1,8}, {5,8,0}, {5,0,7}, {8,3,0}, {2,6,4} }
},
/* #159 */
{
	6,
	{ 6, 4, 4, 5, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 6, 7, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {2,1,4}, {2,4,5}, {5,4,3}, {5,3,0}, {-1,-1,-1} }
},
/* #160 */
{
	4,
	{ 6, 4, 1, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 5, 7,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,3,2}, {0,2,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #161 */
{
	7,
	{ 0, 6, 4, 0, 0, 1, 3,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 2, 4, 5, 7,-1,-1,-1,-1,-1},
	3,
	{ {1,6,5}, {1,5,2}, {4,0,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #162 */
{
	5,
	{ 0, 6, 4, 1, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 3, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {3,0,4}, {4,0,1}, {1,0,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #163 */
{
	6,
	{ 6, 4, 0, 1, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 2, 3, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {2,5,3}, {5,2,0}, {0,2,4}, {4,1,0}, {-1,-1,-1} }
},
/* #164 */
{
	7,
	{ 2, 6, 4, 0, 1, 3, 2,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 2, 5, 7, 6,-1,-1,-1,-1,-1},
	3,
	{ {4,2,1}, {4,1,5}, {0,6,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #165 */
{
	8,
	{ 0, 2, 6, 4, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {3,6,5}, {3,2,6}, {4,1,7}, {4,0,1}, {-1,-1,-1} }
},
/* #166 */
{
	8,
	{ 0, 2, 6, 4, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 2, 3, 7, 6,-1,-1,-1,-1},
	4,
	{ {6,5,0}, {6,0,2}, {2,0,3}, {1,7,4}, {-1,-1,-1} }
},
/* #167 */
{
	7,
	{ 2, 6, 4, 1, 0, 3, 2,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 3, 4, 7, 6,-1,-1,-1,-1,-1},
	5,
	{ {2,1,5}, {2,5,3}, {4,3,0}, {4,0,6}, {2,3,4} }
},
/* #168 */
{
	5,
	{ 2, 6, 4, 1, 1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 3, 5,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,2,3}, {3,2,0}, {0,2,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #169 */
{
	8,
	{ 0, 2, 6, 4, 0, 1, 0, 1,-1,-1,-1,-1},
	{ 1, 3, 7, 5, 2, 3, 4, 5,-1,-1,-1,-1},
	4,
	{ {5,7,3}, {5,3,1}, {1,3,2}, {0,4,6}, {-1,-1,-1} }
},
/* #170 */
{
	4,
	{ 0, 2, 6, 4,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 5,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,3,1}, {3,2,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #171 */
{
	5,
	{ 2, 6, 4, 0, 0,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 5, 2, 4,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {3,4,0}, {4,2,0}, {2,1,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #172 */
{
	6,
	{ 6, 4, 0, 1, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 2, 3, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {5,1,0}, {1,5,2}, {1,2,4}, {3,4,2}, {-1,-1,-1} }
},
/* #173 */
{
	7,
	{ 0, 6, 4, 1, 0, 1, 2,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 3, 4, 5, 6,-1,-1,-1,-1,-1},
	5,
	{ {6,4,0}, {6,0,3}, {1,3,5}, {1,5,2}, {6,3,1} }
},
/* #174 */
{
	5,
	{ 0, 6, 4, 0, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 5, 2, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,3,1}, {3,0,1}, {0,2,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #175 */
{
	4,
	{ 6, 4, 0, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 5, 4, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,3,2}, {1,0,3}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #176 */
{
	5,
	{ 6, 4, 0, 1, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 6, 4, 5, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,4,1}, {1,4,2}, {2,4,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #177 */
{
	6,
	{ 0, 6, 0, 4, 1, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 2, 6, 5, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {1,2,3}, {2,1,5}, {2,5,0}, {4,0,5}, {-1,-1,-1} }
},
/* #178 */
{
	6,
	{ 0, 6, 4, 1, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 6, 3, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {5,3,0}, {5,0,4}, {5,4,1}, {1,4,2}, {-1,-1,-1} }
},
/* #179 */
{
	5,
	{ 6, 0, 4, 1, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 2, 6, 3, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,4,2}, {4,3,2}, {3,1,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #180 */
{
	8,
	{ 2, 6, 0, 4, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 3, 7, 2, 6, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {3,1,6}, {3,6,4}, {4,6,5}, {7,2,0}, {-1,-1,-1} }
},
/* #181 */
{
	7,
	{ 0, 2, 6, 4, 1, 3, 2,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 6, 5, 7, 6,-1,-1,-1,-1,-1},
	5,
	{ {0,1,6}, {0,6,3}, {4,3,2}, {4,2,5}, {0,3,4} }
},
/* #182 */
{
	9,
	{ 0, 2, 6, 0, 4, 1, 0, 3, 2,-1,-1,-1},
	{ 1, 3, 7, 2, 6, 3, 4, 7, 6,-1,-1,-1},
	5,
	{ {2,7,5}, {2,5,6}, {2,6,4}, {5,0,6}, {8,3,1} }
},
/* #183 */
{
	6,
	{ 2, 6, 4, 1, 3, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 6, 3, 7, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {1,4,3}, {1,3,2}, {2,3,0}, {2,0,5}, {-1,-1,-1} }
},
/* #184 */
{
	6,
	{ 2, 6, 4, 1, 0, 1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 6, 3, 4, 5,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,3,5}, {3,4,0}, {0,4,2}, {2,1,0}, {-1,-1,-1} }
},
/* #185 */
{
	7,
	{ 0, 2, 6, 0, 4, 1, 1,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 2, 6, 3, 5,-1,-1,-1,-1,-1},
	5,
	{ {2,1,5}, {2,5,6}, {4,6,0}, {4,0,3}, {2,6,4} }
},
/* #186 */
{
	5,
	{ 0, 2, 6, 4, 0,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 7, 6, 4,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,3,0}, {3,2,0}, {2,1,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #187 */
{
	4,
	{ 2, 6, 0, 4,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 7, 2, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,1,0}, {2,3,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #188 */
{
	7,
	{ 6, 0, 4, 1, 0, 1, 2,-1,-1,-1,-1,-1},
	{ 7, 2, 6, 3, 4, 5, 6,-1,-1,-1,-1,-1},
	5,
	{ {5,4,2}, {5,2,0}, {3,0,6}, {3,6,1}, {5,0,3} }
},
/* #189 */
{
	6,
	{ 0, 6, 4, 1, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 6, 3, 5, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,5,2}, {3,4,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #190 */
{
	6,
	{ 0, 6, 0, 4, 0, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 7, 2, 6, 4, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {5,2,0}, {5,0,1}, {1,0,4}, {1,4,3}, {-1,-1,-1} }
},
/* #191 */
{
	3,
	{ 6, 4, 2,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 7, 6, 6,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {0,2,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #192 */
{
	4,
	{ 4, 5, 3, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 6, 7, 7, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,3,2}, {0,2,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #193 */
{
	7,
	{ 0, 0, 4, 5, 0, 3, 2,-1,-1,-1,-1,-1},
	{ 1, 2, 6, 7, 4, 7, 6,-1,-1,-1,-1,-1},
	3,
	{ {5,3,2}, {5,2,6}, {1,4,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #194 */
{
	7,
	{ 0, 4, 5, 1, 1, 3, 2,-1,-1,-1,-1,-1},
	{ 1, 6, 7, 3, 5, 7, 6,-1,-1,-1,-1,-1},
	3,
	{ {1,6,5}, {1,5,2}, {4,3,0}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #195 */
{
	8,
	{ 0, 4, 5, 1, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 2, 6, 7, 3, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {2,7,6}, {2,1,7}, {5,0,4}, {5,3,0}, {-1,-1,-1} }
},
/* #196 */
{
	5,
	{ 2, 0, 4, 5, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 2, 6, 7, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,3,0}, {0,3,1}, {1,3,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #197 */
{
	6,
	{ 0, 2, 4, 5, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 6, 7, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,3,2}, {3,4,0}, {3,0,5}, {1,5,0}, {-1,-1,-1} }
},
/* #198 */
{
	8,
	{ 0, 2, 0, 4, 5, 1, 1, 3,-1,-1,-1,-1},
	{ 1, 3, 2, 6, 7, 3, 5, 7,-1,-1,-1,-1},
	4,
	{ {1,7,4}, {1,4,2}, {2,4,3}, {5,0,6}, {-1,-1,-1} }
},
/* #199 */
{
	7,
	{ 2, 4, 5, 1, 0, 1, 3,-1,-1,-1,-1,-1},
	{ 3, 6, 7, 3, 4, 5, 7,-1,-1,-1,-1,-1},
	5,
	{ {4,5,3}, {4,3,0}, {1,0,6}, {1,6,2}, {4,0,1} }
},
/* #200 */
{
	5,
	{ 2, 4, 5, 1, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 6, 7, 3, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,3,4}, {4,3,1}, {1,3,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #201 */
{
	8,
	{ 0, 2, 0, 4, 5, 1, 0, 2,-1,-1,-1,-1},
	{ 1, 3, 2, 6, 7, 3, 4, 6,-1,-1,-1,-1},
	4,
	{ {7,1,5}, {7,5,3}, {3,5,4}, {2,6,0}, {-1,-1,-1} }
},
/* #202 */
{
	6,
	{ 0, 2, 4, 5, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 6, 7, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {0,5,1}, {5,0,2}, {2,0,4}, {4,3,2}, {-1,-1,-1} }
},
/* #203 */
{
	7,
	{ 2, 0, 4, 5, 0, 1, 2,-1,-1,-1,-1,-1},
	{ 3, 2, 6, 7, 4, 5, 6,-1,-1,-1,-1,-1},
	5,
	{ {3,2,6}, {3,6,0}, {5,0,1}, {5,1,4}, {3,0,5} }
},
/* #204 */
{
	4,
	{ 0, 4, 5, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 2, 6, 7, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,2,0}, {2,1,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #205 */
{
	5,
	{ 0, 4, 5, 1, 0,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 6, 7, 3, 4,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,0,1}, {0,3,1}, {3,2,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #206 */
{
	5,
	{ 0, 0, 4, 5, 1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 2, 6, 7, 5,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,4,1}, {4,3,1}, {3,2,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #207 */
{
	4,
	{ 4, 5, 0, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 6, 7, 4, 5,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,2,3}, {1,0,2}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #208 */
{
	5,
	{ 4, 5, 0, 3, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 7, 4, 7, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,2,1}, {1,2,3}, {3,2,4}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #209 */
{
	6,
	{ 0, 4, 0, 5, 3, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 2, 7, 7, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,2,5}, {2,4,0}, {0,4,3}, {3,1,0}, {-1,-1,-1} }
},
/* #210 */
{
	8,
	{ 0, 4, 5, 1, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 1, 5, 7, 3, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {2,1,4}, {2,4,6}, {6,4,7}, {5,3,0}, {-1,-1,-1} }
},
/* #211 */
{
	7,
	{ 4, 0, 5, 1, 1, 3, 2,-1,-1,-1,-1,-1},
	{ 5, 2, 7, 3, 5, 7, 6,-1,-1,-1,-1,-1},
	5,
	{ {6,5,2}, {6,2,0}, {1,0,4}, {1,4,3}, {6,0,1} }
},
/* #212 */
{
	6,
	{ 2, 4, 0, 5, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 2, 7, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,2,0}, {4,0,5}, {4,5,1}, {1,5,3}, {-1,-1,-1} }
},
/* #213 */
{
	5,
	{ 0, 2, 4, 5, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 7, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,3,1}, {3,2,1}, {2,0,1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #214 */
{
	9,
	{ 0, 2, 4, 0, 5, 1, 0, 1, 3,-1,-1,-1},
	{ 1, 3, 5, 2, 7, 3, 4, 5, 7,-1,-1,-1},
	5,
	{ {2,6,3}, {2,3,8}, {2,8,4}, {3,1,8}, {7,5,0} }
},
/* #215 */
{
	6,
	{ 2, 4, 5, 1, 1, 3,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 7, 3, 5, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,3,0}, {4,0,1}, {1,0,5}, {1,5,2}, {-1,-1,-1} }
},
/* #216 */
{
	6,
	{ 2, 4, 5, 1, 0, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 7, 3, 4, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {1,3,2}, {3,1,4}, {3,4,0}, {5,0,4}, {-1,-1,-1} }
},
/* #217 */
{
	7,
	{ 0, 2, 4, 0, 5, 1, 2,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 2, 7, 3, 6,-1,-1,-1,-1,-1},
	5,
	{ {2,0,3}, {2,3,6}, {4,6,1}, {4,1,5}, {2,6,4} }
},
/* #218 */
{
	7,
	{ 0, 2, 4, 5, 0, 1, 2,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 7, 4, 5, 6,-1,-1,-1,-1,-1},
	5,
	{ {1,0,5}, {1,5,3}, {6,3,2}, {6,2,4}, {1,3,6} }
},
/* #219 */
{
	6,
	{ 2, 4, 0, 5, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 2, 7, 5, 6,-1,-1,-1,-1,-1,-1},
	2,
	{ {1,4,3}, {2,5,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #220 */
{
	5,
	{ 4, 0, 5, 1, 0,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 2, 7, 3, 4,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,4,2}, {4,1,2}, {1,3,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #221 */
{
	4,
	{ 0, 4, 5, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 7, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,1,0}, {3,2,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #222 */
{
	6,
	{ 0, 4, 0, 5, 0, 1,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 2, 7, 4, 5,-1,-1,-1,-1,-1,-1},
	4,
	{ {1,4,2}, {1,2,3}, {3,2,0}, {3,0,5}, {-1,-1,-1} }
},
/* #223 */
{
	3,
	{ 4, 5, 1,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 7, 5,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {0,2,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #224 */
{
	5,
	{ 4, 4, 1, 3, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 6, 5, 7, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {1,4,0}, {0,4,2}, {2,4,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #225 */
{
	8,
	{ 0, 4, 0, 4, 0, 1, 3, 2,-1,-1,-1,-1},
	{ 1, 5, 2, 6, 4, 5, 7, 6,-1,-1,-1,-1},
	4,
	{ {1,3,7}, {1,7,5}, {5,7,6}, {4,0,2}, {-1,-1,-1} }
},
/* #226 */
{
	6,
	{ 0, 4, 4, 1, 3, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 6, 3, 7, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {2,0,1}, {0,2,5}, {0,5,3}, {4,3,5}, {-1,-1,-1} }
},
/* #227 */
{
	7,
	{ 4, 0, 4, 1, 0, 3, 2,-1,-1,-1,-1,-1},
	{ 5, 2, 6, 3, 4, 7, 6,-1,-1,-1,-1,-1},
	5,
	{ {3,1,4}, {3,4,0}, {5,0,2}, {5,2,6}, {3,0,5} }
},
/* #228 */
{
	6,
	{ 2, 4, 0, 4, 1, 3,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 2, 6, 5, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,0,5}, {0,4,2}, {2,4,1}, {1,3,2}, {-1,-1,-1} }
},
/* #229 */
{
	7,
	{ 0, 2, 4, 4, 0, 1, 3,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 6, 4, 5, 7,-1,-1,-1,-1,-1},
	5,
	{ {6,5,2}, {6,2,3}, {1,3,4}, {1,4,0}, {6,3,1} }
},
/* #230 */
{
	7,
	{ 0, 2, 4, 0, 4, 1, 3,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 2, 6, 3, 7,-1,-1,-1,-1,-1},
	5,
	{ {4,3,1}, {4,1,6}, {2,6,5}, {2,5,0}, {4,6,2} }
},
/* #231 */
{
	6,
	{ 2, 4, 4, 1, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 6, 3, 4, 7,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,4,1}, {0,5,3}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #232 */
{
	6,
	{ 2, 4, 4, 1, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 6, 3, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {5,0,3}, {5,3,4}, {5,4,2}, {2,4,1}, {-1,-1,-1} }
},
/* #233 */
{
	9,
	{ 0, 2, 4, 0, 4, 1, 0, 1, 2,-1,-1,-1},
	{ 1, 3, 5, 2, 6, 3, 4, 5, 6,-1,-1,-1},
	5,
	{ {4,8,1}, {4,1,7}, {4,7,2}, {1,5,7}, {6,0,3} }
},
/* #234 */
{
	5,
	{ 0, 2, 4, 4, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 6, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {3,4,2}, {4,1,2}, {1,0,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #235 */
{
	6,
	{ 2, 4, 0, 4, 0, 2,-1,-1,-1,-1,-1,-1},
	{ 3, 5, 2, 6, 4, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {3,5,0}, {3,0,1}, {1,0,2}, {1,2,4}, {-1,-1,-1} }
},
/* #236 */
{
	5,
	{ 4, 0, 4, 1, 1,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 2, 6, 3, 5,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {4,0,3}, {0,2,3}, {2,1,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #237 */
{
	6,
	{ 0, 4, 4, 1, 0, 1,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 6, 3, 4, 5,-1,-1,-1,-1,-1,-1},
	4,
	{ {4,0,3}, {4,3,2}, {2,3,5}, {2,5,1}, {-1,-1,-1} }
},
/* #238 */
{
	4,
	{ 0, 4, 0, 4,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 5, 2, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {0,3,2}, {0,1,3}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #239 */
{
	3,
	{ 4, 4, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 5, 6, 4,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {1,2,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #240 */
{
	4,
	{ 0, 1, 3, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 4, 5, 7, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,1,3}, {1,0,3}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #241 */
{
	5,
	{ 0, 0, 1, 3, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 2, 5, 7, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,1,2}, {1,4,2}, {4,3,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #242 */
{
	5,
	{ 0, 1, 0, 3, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 4, 7, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {1,0,3}, {0,2,3}, {2,4,3}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #243 */
{
	4,
	{ 0, 1, 3, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 2, 3, 7, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,1,0}, {3,2,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #244 */
{
	5,
	{ 2, 0, 0, 1, 3,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 2, 4, 5, 7,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {1,0,2}, {0,4,2}, {4,3,2}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #245 */
{
	4,
	{ 0, 2, 1, 3,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 5, 7,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,0,1}, {3,2,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #246 */
{
	6,
	{ 0, 2, 0, 1, 0, 3,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 2, 3, 4, 7,-1,-1,-1,-1,-1,-1},
	4,
	{ {2,1,5}, {2,5,4}, {4,5,3}, {4,3,0}, {-1,-1,-1} }
},
/* #247 */
{
	3,
	{ 2, 1, 3,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 3, 7,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {2,1,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #248 */
{
	5,
	{ 2, 1, 0, 1, 2,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 3, 4, 5, 6,-1,-1,-1,-1,-1,-1,-1},
	3,
	{ {0,1,4}, {1,3,4}, {3,2,4}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #249 */
{
	6,
	{ 0, 2, 0, 1, 1, 2,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 2, 3, 5, 6,-1,-1,-1,-1,-1,-1},
	4,
	{ {0,2,5}, {0,5,4}, {4,5,1}, {4,1,3}, {-1,-1,-1} }
},
/* #250 */
{
	4,
	{ 0, 2, 0, 2,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 4, 6,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {2,1,0}, {2,3,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #251 */
{
	3,
	{ 2, 0, 2,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 3, 2, 6,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {2,0,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #252 */
{
	4,
	{ 0, 1, 0, 1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 2, 3, 4, 5,-1,-1,-1,-1,-1,-1,-1,-1},
	2,
	{ {3,0,1}, {3,2,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #253 */
{
	3,
	{ 0, 1, 1,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 3, 5,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {2,0,1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #254 */
{
	3,
	{ 0, 0, 0,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{ 1, 2, 4,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	1,
	{ {2,1,0}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
},
/* #255 */
{
	0,
	{-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	{-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1},
	0,
	{ {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1}, {-1,-1,-1} }
}

#endif	// __MCTABLE_H_
// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
