// Title:   NeighbourTable.h
// Created: Thu Sep 25 15:10:48 2003
// Authors: Richard Keiser, Mark Pauly, Sascha Scandella
//
// Copyright (c) 2001, 2002, 2003, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later
// version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Lesser General Public License for more details.
// 
// You should have received a copy of the GNU Lesser General
// Public License along with this library; if not, write to the
// Free Software Foundation, Inc., 59 Temple Place, Suite 330,
// Boston, MA 02111-1307 USA
// 
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef __NEIGHBOURTABLE_H_
#define __NEIGHBOURTABLE_H_

// Neighbour Tables needed for neighbour accesses

const int neighbourPositions[27][3] = {
	{-1, -1, -1},
	{ 0, -1, -1},
	{ 1, -1, -1},
	{-1,  0, -1},
	{ 0,  0, -1},
	{ 1,  0, -1},
	{-1,  1, -1},
	{ 0,  1, -1},
	{ 1,  1, -1},
	{-1, -1,  0},
	{ 0, -1,  0},
	{ 1, -1,  0},
	{-1,  0,  0},
	{ 0,  0,  0},
	{ 1,  0,  0},
	{-1,  1,  0},
	{ 0,  1,  0},
	{ 1,  1,  0},
	{-1, -1,  1},
	{ 0, -1,  1},
	{ 1, -1,  1},
	{-1,  0,  1},
	{ 0,  0,  1},
	{ 1,  0,  1},
	{-1,  1,  1},
	{ 0,  1,  1},
	{ 1,  1,  1},
};

const int neighbourOffsets[64][3] = {
	{-3, -3, -3},
	{-1, -3, -3},
	{ 1, -3, -3},
	{ 3, -3, -3},
	{-3, -1, -3},
	{-1, -1, -3},
	{ 1, -1, -3},
	{ 3, -1, -3},
	{-3,  1, -3},
	{-1,  1, -3},
	{ 1,  1, -3},
	{ 3,  1, -3},
	{-3,  3, -3},
	{-1,  3, -3},
	{ 1,  3, -3},
	{ 3,  3, -3},
	{-3, -3, -1},
	{-1, -3, -1},
	{ 1, -3, -1},
	{ 3, -3, -1},
	{-3, -1, -1},
	{-1, -1, -1},
	{ 1, -1, -1},
	{ 3, -1, -1},
	{-3,  1, -1},
	{-1,  1, -1},
	{ 1,  1, -1},
	{ 3,  1, -1},
	{-3,  3, -1},
	{-1,  3, -1},
	{ 1,  3, -1},
	{ 3,  3, -1},
	{-3, -3,  1},
	{-1, -3,  1},
	{ 1, -3,  1},
	{ 3, -3,  1},
	{-3, -1,  1},
	{-1, -1,  1},
	{ 1, -1,  1},
	{ 3, -1,  1},
	{-3,  1,  1},
	{-1,  1,  1},
	{ 1,  1,  1},
	{ 3,  1,  1},
	{-3,  3,  1},
	{-1,  3,  1},
	{ 1,  3,  1},
	{ 3,  3,  1},
	{-3, -3,  3},
	{-1, -3,  3},
	{ 1, -3,  3},
	{ 3, -3,  3},
	{-3, -1,  3},
	{-1, -1,  3},
	{ 1, -1,  3},
	{ 3, -1,  3},
	{-3,  1,  3},
	{-1,  1,  3},
	{ 1,  1,  3},
	{ 3,  1,  3},
	{-3,  3,  3},
	{-1,  3,  3},
	{ 1,  3,  3},
	{ 3,  3,  3},
};

static int distValueProjectionTable[8][27] = {
// node 0
{0, 1, 2, 4, 5, 6, 8, 9, 10,
 16, 17, 18, 20, 21, 22, 24, 25, 26,
 32, 33, 34, 36, 37, 38, 40, 41, 42
},
// node 1
{1, 2, 3, 5, 6, 7, 9, 10, 11,
 17, 18, 19, 21, 22, 23, 25, 26, 27,
 33, 34, 35, 37, 38, 39, 41, 42, 43
},
// node 2
{4, 5, 6, 8, 9, 10, 12, 13, 14,
 20, 21, 22, 24, 25, 26, 28, 29, 30,
 36, 37, 38, 40, 41, 42, 44, 45, 46
},
// node 3
{5, 6, 7, 9, 10, 11, 13, 14, 15,
 21, 22, 23, 25, 26, 27, 29, 30, 31, 
 37, 38, 39, 41, 42, 43, 45, 46, 47
},
// node 4
{16, 17, 18, 20, 21, 22, 24, 25, 26,
 32, 33, 34, 36, 37, 38, 40, 41, 42,
 48, 49, 50, 52, 53, 54, 56, 57, 58
},
// node 5
{ 17, 18, 19, 21, 22, 23, 25, 26, 27,
 33, 34, 35, 37, 38, 39, 41, 42, 43,
 49, 50, 51, 53, 54, 55, 57, 58, 59
},
// node 6
{ 20, 21, 22, 24, 25, 26, 28, 29, 30,
 36, 37, 38, 40, 41, 42, 44, 45, 46,
 52, 53, 54, 56, 57, 58, 60, 61, 62
},
// node 7
{21, 22, 23, 25, 26, 27, 29, 30, 31, 
 37, 38, 39, 41, 42, 43, 45, 46, 47,
 53, 54, 55, 57, 58, 59, 61, 62, 63
},
};

// For easier filter handling
struct neighbourHoodInfo {
    int distanceValueProjection[8];
};

// how to project nodes on the neighbourhood grid
static neighbourHoodInfo neighbourHoodTable[27] = {
// node 0	
{
	{0, 1, 4, 5, 16, 17, 20, 21},
},
// node 1
{
	{1, 2, 5, 6, 17, 18, 21, 22},
},
// node 2
{
	{2, 3, 6, 7, 18, 19, 22, 23},
},
// node 3
{
	{4, 5, 8, 9, 20, 21, 24, 25},
},
// node 4
{
	{5, 6, 9, 10, 21, 22, 25, 26},
},
// node 5
{
	{6, 7, 10, 11, 22, 23, 26, 27},
},
// node 6
{
	{8, 9, 12, 13, 24, 25, 28, 29},
},
//node 7
{
	{9, 10, 13, 14, 25, 26, 29, 30},
},
// node 8
{
	{10, 11, 14, 15, 26, 27, 30, 31},
},
// node 9
{
	{16, 17, 20, 21, 32, 33, 36, 37},
},
// node 10
{
	{17, 18, 21, 22, 33, 34, 37, 38},
},
//node 11
{
	{18, 19, 22, 23, 34, 35, 38, 39},
},
// node 12	
{
	{20, 21, 24, 25, 36, 37, 40, 41},
},
// node 13
{
	{21, 22, 25, 26, 37, 38, 41, 42},
},
// node 14
{
	{22, 23, 26, 27, 38, 39, 42, 43},
},
// node 15
{
	{24, 25, 28, 29, 40, 41, 44, 45},
},
// node 16	
{
	{25, 26, 29, 30, 41, 42, 45, 46},
},
// node 17
{
	{26, 27, 30, 31, 42, 43, 46, 47},
},
// node 18
{
	{32, 33, 36, 37, 48, 49, 52, 53},
},
//node 19
{
	{33, 34, 37, 38, 49, 50, 53, 54},
},
// node 20	
{
	{34, 35, 38, 39, 50, 51, 54, 55},
},
// node 21
{
	{36, 37, 40, 41, 52, 53, 56, 57}
},
// node 22
{
	{37, 38, 41, 42, 53, 54, 57, 58},
},
//node 23
{
	{38, 39, 42, 43, 54, 55, 58, 59},
},
// node 24
{
	{40, 41, 44, 45, 56, 57, 60, 61},
},
// node 25
{
	{41, 42, 45, 46, 57, 58, 61, 62},
},
// node 26
{
	{42, 43, 46, 47, 58, 59, 62, 63},
},
};



// For easier filter handling
struct neighbourDistancePositions {
    int neighbourNode[27];
	int distanceValueNumber[27];
	int nbCopyNode[7];
	int nbCopyNodePos[7];
};


// -1 stands for the node itself
static neighbourDistancePositions neighbourDistanceTable[8] = {
// node 0
{
	{0, 1, 1, 3, 4, 4, 3, 4, 4,
	 9, 10, 10, 12, -1, -1, 12, -1, -1,
	 9, 10, 10, 12, -1, -1, 12, -1, -1
	},
	{4, 4, 5, 4, 4, 5, 6, 6, 7,
	 0, 0, 1, 0, 0, 1, 2, 2, 3,
	 4, 4, 5, 4, 4, 5, 6, 6, 7
	},
	{0, 1, 3, 4, 9, 10, 12},
	{7, 6, 5, 4, 3, 2, 1},
},
// node 1
{
	{1, 1, 2, 4, 4, 5, 4, 4, 5,
	 10, 10, 11, -1, -1, 13, -1, -1, 13,
	 10, 10, 11, -1, -1, 13, -1, -1, 13
	},
	{4, 5, 5, 4, 5, 5, 6, 7, 7,
	 0, 1, 1, 0, 1, 1, 2, 3, 3,
	 4, 5, 5, 4, 5, 5, 6, 7, 7
	},
	{1, 2, 4, 5, 10, 11, 13},
	{7, 6, 5, 4, 3, 2, 0},
},
// node 2
{
	{3, 4, 4, 3, 4, 4, 6, 7, 7,
	 12, -1, -1, 12, -1, -1, 14, 15, 15,
	 12, -1, -1, 12, -1, -1, 14, 15, 15
	},
	{4, 4, 5, 6, 6, 7, 4, 4, 5,
	 0, 0, 1, 2, 2, 3, 0, 0, 1,
	 4, 4, 5, 6, 6, 7, 4, 4, 5
	},
	{3, 4, 6, 7, 12, 14, 15},
	{7, 6, 5, 4, 3, 1, 0},
},
// node 3
{
	{4, 4, 5, 4, 4, 5, 7, 7, 8,
	 -1, -1, 13, -1, -1, 13, 15, 15, 16,
	 -1, -1, 13, -1, -1, 13, 15, 15, 16
	},
	{4, 5, 5, 6, 7, 7, 4, 5, 5,
	 0, 1, 1, 2, 3, 3, 0, 1, 1,
	 4, 5, 5, 6, 7, 7, 4, 5, 5
	},
	{4, 5, 7, 8, 13, 15, 16},
	{7, 6, 5, 4, 2, 1, 0},

},
// node 4
{
	{9, 10, 10, 12, -1, -1, 12, -1, -1,
	 9, 10, 10, 12, -1, -1, 12, -1, -1,
	 17, 18, 18, 20, 21, 21, 20, 21, 21,
	},
	{0, 0, 1, 0, 0, 1, 2, 2, 3,
	 4, 4, 5, 4, 4, 5, 6, 6, 7,
	 0, 0, 1, 0, 0, 1, 2, 2, 3
	},
	{9, 10, 12, 17, 18, 20, 21},
	{7, 6, 5, 3, 2, 1, 0},
},
// node 5
{
	{10, 10, 11, -1, -1, 13, -1, -1, 13,
	 10, 10, 11, -1, -1, 13, -1, -1, 13,
	 18, 18, 19, 21, 21, 22, 21, 21, 22
	},
	{0, 1, 1, 0, 1, 1, 2, 3, 3,
	 4, 5, 5, 4, 5, 5, 6, 7, 7, 
	 0, 1, 1, 0, 1, 1, 2, 3, 3
	},
	{10, 11, 13, 18, 19, 21, 22},
	{7, 6, 4, 3, 2, 1, 0},
},
// node 6
{
	{12, -1, -1, 12, -1, -1, 14, 15, 15,
	 12, -1, -1, 12, -1, -1, 14, 15, 15,
	 20, 21, 21, 20, 21, 21, 23, 24, 24
	},
	{0, 0, 1, 2, 2, 3, 0, 0, 1,
	 4, 4, 5, 6, 6, 7, 4, 4, 5,
	 0, 0, 1, 2, 2, 3, 0, 0, 1,
	},
	{12, 14, 15, 20, 21, 23, 24},
	{7, 5, 4, 3, 2, 1, 0},
},
// node 7
{
	{-1, -1, 13, -1, -1, 13, 15, 15, 16,
	 -1, -1, 13, -1, -1, 13, 15, 15, 16,
	 21, 21, 22, 21, 21, 22, 24, 24, 25
	},
	{0, 1, 1, 2, 3, 3, 0, 1, 1,
	 4, 5, 5, 6, 7, 7, 4, 5, 5,
	 0, 1, 1, 2, 3, 3, 0, 1, 1
	},
	{13, 15, 16, 21, 22, 24, 25},
	{6, 5, 4, 3, 2, 1, 0},
},
};

#endif	// __NEIGHBOURTABLE_H_

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
